This is the mail archive of the gdb-patches@sourceware.org mailing list for the GDB project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

Re: [PATCH] Rename i386-nat.h to x86-nat.h for TAGS.


> Here is a simple one that someone overlooked.
> 
> Ok?

Thanks for the patch, and sorry for taking months before replying.
Feel free to ping us a couple of weeks after submission, and every
week thereafter. We should have picked up on your patch months ago,
since it was so trivial.

Attached is what I just checked in. A quick grep of the entire set
of sources revealed a couple more locations where we still referenced
the old file names.

> 
> Can someone apply it if approved, thanks.  I formatted this with format-patch, but format-patch I bet wonât work with Mail.  :-(  As for git-email, well, I donât have that set up, and the system that sends email isnât the system I develop on.
> 
>  gdb/Makefile.in | 2 +-
>  1 file changed, 1 insertion(+), 1 deletion(-)
> 
> diff --git a/gdb/Makefile.in b/gdb/Makefile.in
> index faa6c86..04251a4 100644
> --- a/gdb/Makefile.in
> +++ b/gdb/Makefile.in
> @@ -959,7 +959,7 @@ psymtab.h psympriv.h progspace.h bfin-tdep.h \
>  amd64-darwin-tdep.h charset-list.h \
>  config/djgpp/langinfo.h config/djgpp/nl_types.h darwin-nat.h \
>  dicos-tdep.h filesystem.h gcore.h gdb_wchar.h hppabsd-tdep.h \
> -i386-darwin-tdep.h i386-nat.h linux-record.h moxie-tdep.h nios2-tdep.h \
> +i386-darwin-tdep.h x86-nat.h linux-record.h moxie-tdep.h nios2-tdep.h \
>  ft32-tdep.h \
>  osdata.h procfs.h python/py-event.h python/py-events.h python/py-stopevent.h \
>  python/python-internal.h python/python.h ravenscar-thread.h record.h \
> -- 
> 1.9.1

-- 
Joel
>From 030f17b5eb56b6e48588f6da015e05f568144692 Mon Sep 17 00:00:00 2001
From: Joel Brobecker <brobecker@adacore.com>
Date: Sun, 6 Dec 2015 18:38:24 +0100
Subject: [PATCH] Replace remaining references to i386-nat with x86-nat
 instead.

i386-nat.[hc] got renamed to x86-nat.[hc] a while back, but somehow
3 references to the old file name remained past the renaming. This
fixes all of them.

gdb/ChangeLog (with Mike Stump <mikestump@comcast.net>):

        * Makefile.in (TAGS): Replace i386-nat.h by x86-nat.h.
        * x86-nat.c: Replace remaining references to i386-nat
        by reference to x86-nat instead.
---
 gdb/ChangeLog   | 7 +++++++
 gdb/Makefile.in | 2 +-
 gdb/x86-nat.c   | 4 ++--
 3 files changed, 10 insertions(+), 3 deletions(-)

diff --git a/gdb/ChangeLog b/gdb/ChangeLog
index 3fda785..9bbf827 100644
--- a/gdb/ChangeLog
+++ b/gdb/ChangeLog
@@ -1,3 +1,10 @@
+2015-12-06  Mike Stump <mikestump@comcast.net>
+	    Joel Brobecker  <brobecker@adacore.com>
+
+	* Makefile.in (TAGS): Replace i386-nat.h by x86-nat.h.
+	* x86-nat.c: Replace remaining references to i386-nat
+	by reference to x86-nat instead.
+
 2015-12-05  Joel Brobecker  <brobecker@adacore.com>
 
 	GDB 7.10.1 released.
diff --git a/gdb/Makefile.in b/gdb/Makefile.in
index 14ad405..3eadbbc 100644
--- a/gdb/Makefile.in
+++ b/gdb/Makefile.in
@@ -965,7 +965,7 @@ psymtab.h psympriv.h progspace.h bfin-tdep.h \
 amd64-darwin-tdep.h charset-list.h \
 config/djgpp/langinfo.h config/djgpp/nl_types.h darwin-nat.h \
 dicos-tdep.h filesystem.h gcore.h gdb_wchar.h hppabsd-tdep.h \
-i386-darwin-tdep.h i386-nat.h linux-record.h moxie-tdep.h nios2-tdep.h \
+i386-darwin-tdep.h x86-nat.h linux-record.h moxie-tdep.h nios2-tdep.h \
 ft32-tdep.h \
 osdata.h procfs.h python/py-event.h python/py-events.h python/py-stopevent.h \
 python/python-internal.h python/python.h ravenscar-thread.h record.h \
diff --git a/gdb/x86-nat.c b/gdb/x86-nat.c
index bfdf0d0..b465dc8 100644
--- a/gdb/x86-nat.c
+++ b/gdb/x86-nat.c
@@ -107,7 +107,7 @@ x86_debug_reg_state (pid_t pid)
   return &x86_process_info_get (pid)->state;
 }
 
 /* See declaration in i386-nat.h.  */
 
 void
 x86_forget_process (pid_t pid)
@@ -251,7 +251,7 @@ x86_remove_hw_breakpoint (struct target_ops *self, struct gdbarch *gdbarch,
    extreme example, consider the case where all the watchpoints watch
    the same address and the same region length: then we can handle a
    virtually unlimited number of watchpoints, due to debug register
-   sharing implemented via reference counts in i386-nat.c.  */
+   sharing implemented via reference counts in x86-nat.c.  */
 
 static int
 x86_can_use_hw_breakpoint (struct target_ops *self,
@@ -107,7 +107,7 @@ x86_debug_reg_state (pid_t pid)
 }
 
-/* See declaration in i386-nat.h.  */
+/* See declaration in x86-nat.h.  */
 
 void
-- 
2.1.4


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]